.. _function_usage_examples:

**************************************************
Typical Tasks for Computing Correlation Functions
**************************************************

Here we present docstrings of the most commonly used functions and classes
grouped together by functionality.
Many docstrings contain example code to demonstrate basic usage.
For documentation of functions not listed here, see :py:mod:`Corrfunc`.

Reading input data
~~~~~~~~~~~~~~~~~~

.. toctree::
   :maxdepth: 1

   read_catalog

Creating a file with bins for the clustering statistics
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. toctree::
   :maxdepth: 1

   generate_bins

Choosing the correlation function 
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. toctree::
   :maxdepth: 1

   which_corrfunc
   

Calculating Correlation Functions on Simulations
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. toctree::
   :maxdepth: 1

   converting_3d_counts
   converting_rp_pi_counts
   computing_wp_and_xi
   theory_functions
   rr_autocorrelations

Calculating Correlation Functions on Mock Catalogs
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. toctree::
   :maxdepth: 1

   converting_rp_pi_mocks
   converting_ddtheta_mocks
   mock_functions
                       
Weighted Correlation Functions
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. toctree::
   :maxdepth: 1
   
   weighted_correlations
   custom_weighting
